You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by aj...@apache.org on 2006/02/04 13:22:00 UTC

svn commit: r374862 [1/2] - in /webservices/axis2/trunk/java/modules: adb/src/org/apache/axis2/databinding/utils/ adb/test/org/apache/axis2/databinding/utils/ codegen/ codegen/src/org/apache/axis2/schema/ codegen/src/org/apache/axis2/schema/template/ c...

Author: ajith
Date: Sat Feb  4 04:20:54 2006
New Revision: 374862

URL: http://svn.apache.org/viewcvs?rev=374862&view=rev
Log:
Completely rewrote the deserialization logic of the ADB classes
1. Added statemachines to process the readers
2. Added support for OM elements and OM element arrays
3. Now the name matchings are done on a QName basis
4. Changed the test classes to suit the name matching change in 3
5. Moved some classes around!

Notes
* Only the sequences are correctly processed. choice and all need to be catered for
* the serialization logic of arrays have a prob. Need to fix the ADBPullparser. The perf2 test is 
  commented because of the issue

Added:
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnonComplexTypeTest.java
      - copied, changed from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateAnonComplexTypeTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnyTypeTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayInArrayTest.java
      - copied, changed from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayInArrayTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayTest.java
      - copied, changed from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayTest.java
Removed:
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateAnonComplexTypeTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayInArrayTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayTest.java
Modified:
    webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/ConverterUtil.java
    webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleArrayReaderStateMachine.java
    webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleElementReaderStateMachine.java
    webservices/axis2/trunk/java/modules/adb/test/org/apache/axis2/databinding/utils/NamedStaxOMBuilderTest.java
    webservices/axis2/trunk/java/modules/codegen/maven.xml
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/BeanWriterMetaInfoHolder.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/SchemaCompiler.java
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/template/ADBBeanTemplate.xsl
    webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/writer/JavaBeanWriter.java
    webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/anonymous_complexType.xsd
    webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_anytype.xsd
    webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_sequence.xsd
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeBytePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntegerPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeLongPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNegativeIntegerPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonNegativeIntegerPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonPositiveIntegerPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypePositveIntegerPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeShortPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedBytePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedIntPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedLongPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedShortPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeAnyURIPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBase64BinPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBooleanPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDatePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDateTimePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDayPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDoublePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDurationPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeFloatPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeHexBinaryPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeMonthDayPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeQNamePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeTimePopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypegMonthPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypegYearMonthPopulateTest.java
    webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypegYearPopulateTest.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
    webservices/axis2/trunk/java/modules/integration/project.xml

Modified: webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/ConverterUtil.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/ConverterUtil.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/ConverterUtil.java (original)
+++ webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/ConverterUtil.java Sat Feb  4 04:20:54 2006
@@ -48,6 +48,7 @@
 import java.util.GregorianCalendar;
 import java.util.List;
 import java.util.TimeZone;
+import java.util.ArrayList;
 import java.io.ByteArrayInputStream;
 /*
  * Copyright 2004,2005 The Apache Software Foundation.
@@ -613,6 +614,18 @@
     }
 
     /* list to array conversion methods */
+
+    public static Object convertToArray(Class baseArrayClass, String[] valueArray) {
+          //create a list using the string array
+        List valuesList = new ArrayList(valueArray.length);
+        for (int i = 0; i < valueArray.length; i++) {
+            valuesList.add(valueArray[i]);
+
+        }
+
+        return convertToArray(baseArrayClass, valuesList);
+    }
+
 
     /**
      * @param baseArrayClass

Modified: webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleArrayReaderStateMachine.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleArrayReaderStateMachine.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleElementReaderStateMachine.java (original)
+++ webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleElementReaderStateMachine.java Sat Feb  4 04:20:54 2006
@@ -33,14 +33,26 @@
     private int currentState = INIT_STATE;
     private String text="";
 
+    /**
+     *
+     * @return
+     */
     public String getText() {
         return text;
     }
 
+    /**
+     * the Qname of the element to be tested
+     * @param elementNameToTest
+     */
     public void setElementNameToTest(QName elementNameToTest) {
         this.elementNameToTest = elementNameToTest;
     }
 
+    /**
+     * Resets the state machine. Once the reset is called
+     * the state machine is good enough for a fresh run
+     */
     public void reset(){
         elementNameToTest = null;
         currentState = INIT_STATE;
@@ -73,6 +85,10 @@
     }
 
 
+    /**
+     * Updates the state depending on the parser
+     * @param reader
+     */
     private void updateState(XMLStreamReader reader){
         int event = reader.getEventType();
 

Modified: webservices/axis2/trunk/java/modules/adb/test/org/apache/axis2/databinding/utils/NamedStaxOMBuilderTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/adb/test/org/apache/axis2/databinding/utils/NamedStaxOMBuilderTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/adb/test/org/apache/axis2/databinding/utils/NamedStaxOMBuilderTest.java (original)
+++ webservices/axis2/trunk/java/modules/adb/test/org/apache/axis2/databinding/utils/NamedStaxOMBuilderTest.java Sat Feb  4 04:20:54 2006
@@ -4,11 +4,11 @@
 
 import javax.xml.stream.XMLStreamReader;
 import javax.xml.stream.XMLInputFactory;
-import javax.xml.stream.XMLStreamException;
 import javax.xml.namespace.QName;
 import java.io.StringReader;
 
 import org.apache.ws.commons.om.OMElement;
+import org.apache.axis2.util.StreamWrapper;
 /*
  * Copyright 2004,2005 The Apache Software Foundation.
  *
@@ -27,7 +27,7 @@
 
 public class NamedStaxOMBuilderTest extends TestCase {
 
-    public void testNamedOMBulder() throws Exception{
+    public void testNamedOMBuilder() throws Exception{
 
         String xmlDoc="<wrapper><myIntVal>200</myIntVal></wrapper>";
         XMLStreamReader reader = XMLInputFactory.newInstance().createXMLStreamReader(
@@ -37,9 +37,45 @@
         OMElement elt = sm.getOMElement();
 
         assertNotNull(elt);
+        assertEquals(elt.getLocalName(),"wrapper");
+
+
+
+
+    }
+
+    public void testNamedOMBuilder1() throws Exception{
+
+        String xmlDoc="<wrapper><myIntVal>200</myIntVal></wrapper>";
+        XMLStreamReader reader = XMLInputFactory.newInstance().createXMLStreamReader(
+                new StringReader(xmlDoc));
+
+        //move upto the  myIntVal start element first
+        boolean done = false;
+        QName nameToMatch = new QName("myIntVal");
+        while(!done){
+            if (reader.isStartElement() && nameToMatch.equals(reader.getName())){
+                done = true;
+            }else{
+                reader.next();
+            }
+        }
+
+        //we need the wrapper here - it is the nature of the builders that
+        //they expect the *next* event to be the start element (not the
+        //current one) So we need the wrapper to simulate a full fledged
+        //
+        NamedStaxOMBuilder  sm = new NamedStaxOMBuilder(
+                new StreamWrapper(reader),nameToMatch);
+        OMElement elt = sm.getOMElement();
+
+        assertNotNull(elt);
+        assertEquals(elt.getLocalName(),"myIntVal");
+
 
 
 
     }
+
 
 }

Modified: webservices/axis2/trunk/java/modules/codegen/maven.xml
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/maven.xml?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/maven.xml (original)
+++ webservices/axis2/trunk/java/modules/codegen/maven.xml Sat Feb  4 04:20:54 2006
@@ -65,6 +65,14 @@
             <arg file="${schema.generated.src.dir}"/>
         </java>
 
+        <!-- simple any type xsd -->
+        <java classname="org.apache.axis2.schema.XSD2Java" fork="true">
+            <classpath refid="maven.dependency.classpath"/>
+            <classpath location="${compiled.classes.dir}"/>
+            <arg file="${schema.source.dir}/simple_anytype.xsd"/>
+            <arg file="${schema.generated.src.dir}"/>
+        </java>
+
         <!-- ################################################################### -->
         <!-- All simple primitive types xsd -->
         <java classname="org.apache.axis2.schema.XSD2Java" fork="true">
@@ -74,7 +82,7 @@
             <arg file="${schema.generated.src.dir}"/>
         </java>
 
-           <!-- All simple derived types xsd -->
+        <!-- All simple derived types xsd -->
         <java classname="org.apache.axis2.schema.XSD2Java" fork="true">
             <classpath refid="maven.dependency.classpath"/>
             <classpath location="${compiled.classes.dir}"/>

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/BeanWriterMetaInfoHolder.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/BeanWriterMetaInfoHolder.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/BeanWriterMetaInfoHolder.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/BeanWriterMetaInfoHolder.java Sat Feb  4 04:20:54 2006
@@ -115,7 +115,7 @@
         return extension;
     }
 
-    
+
 
     /**
      * Sets the extension status.
@@ -332,12 +332,21 @@
         Arrays.sort(keys);
 
         //Now refill the Ordered QName Array
-        QName[] returnQNames = new QName[count];
+        List returnQNames = new ArrayList();
         for (int i = 0; i < keys.length; i++) {
-            returnQNames[i] = (QName) qNameOrderMap.get(keys[i]);
+            returnQNames.add(qNameOrderMap.get(keys[i]));
+        }
 
+        //we've missed the attributes, so if there are attributes
+        //add them explicitly to the end of this list
+        QName[] allNames = getQNameArray();
+        for (int i = 0; i < allNames.length; i++) {
+            if(getAttributeStatusForQName(allNames[i])){
+              returnQNames.add(allNames[i]);
+            }
         }
-        return returnQNames;
+
+        return (QName[])returnQNames.toArray(new QName[returnQNames.size()]);
     }
 
     /**
@@ -345,7 +354,7 @@
      * @return the starting number for the sequence
      */
     public int getOrderStartPoint(){
-          return qNameOrderMap.size();
+        return qNameOrderMap.size();
     }
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/SchemaCompiler.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/SchemaCompiler.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/SchemaCompiler.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/SchemaCompiler.java Sat Feb  4 04:20:54 2006
@@ -92,6 +92,7 @@
     private static final String EXTRA_ATTRIBUTE_FIELD_NAME = "extraAttributes";
 
     public static final String DEFAULT_CLASS_NAME = OMElement.class.getName();
+    public static final String DEFAULT_CLASS_ARRAY_NAME = "org.apache.ws.commons.om.OMElement[]";
 
 
     /**
@@ -685,17 +686,17 @@
      */
     private void processParticle(XmlSchemaParticle particle, //particle being processed
                                  BeanWriterMetaInfoHolder metainfHolder // metainf holder
-            ,XmlSchema parenSchema) throws SchemaCompilationException {
+            ,XmlSchema parentSchema) throws SchemaCompilationException {
         if (particle instanceof XmlSchemaSequence) {
             XmlSchemaObjectCollection items = ((XmlSchemaSequence) particle).getItems();
-            process(items, metainfHolder, true,parenSchema);
+            process(items, metainfHolder, true,parentSchema);
         } else if (particle instanceof XmlSchemaAll) {
             XmlSchemaObjectCollection items = ((XmlSchemaAll) particle).getItems();
-            process(items, metainfHolder, false,parenSchema);
+            process(items, metainfHolder, false,parentSchema);
         } else if (particle instanceof XmlSchemaChoice) {
             XmlSchemaObjectCollection items = ((XmlSchemaChoice) particle).getItems();
             metainfHolder.setChoice(true);
-            process(items, metainfHolder, false,parenSchema);
+            process(items, metainfHolder, false,parentSchema);
 
         }
     }

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/template/ADBBeanTemplate.xsl
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/template/ADBBeanTemplate.xsl?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/template/ADBBeanTemplate.xsl (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/template/ADBBeanTemplate.xsl Sat Feb  4 04:20:54 2006
@@ -172,7 +172,8 @@
                             elementList.add(<xsl:value-of select="$varName"/>);
                         </xsl:when>
                         <xsl:when test="@array">
-                            elementList.add("<xsl:value-of select="$propertyName"/>");
+                            elementList.add(new javax.xml.namespace.QName("<xsl:value-of select="$namespace"/>",
+                                                                      "<xsl:value-of select="$propertyName"/>"));
                             elementList.add(<xsl:value-of select="$varName"/>);
                         </xsl:when>
                         <xsl:otherwise>
@@ -241,134 +242,202 @@
         <xsl:value-of select="$name"/> object = new <xsl:value-of select="$name"/>();
         try {
         int event = reader.getEventType();
-        int count = 0;
-        int argumentCount = <xsl:value-of select="count(property)"/> ;
-        boolean done =false;
+
         //event better be a START_ELEMENT. if not we should go up to the start element here
         while (!reader.isStartElement()){
-        event = reader.next();
+             reader.next();
+        }
+
+        <xsl:if test="not(@type)">
+        if (!MY_QNAME.equals(reader.getName())){
+                    throw new Exception("Wrong QName");
         }
-        <!-- First loop creates arrayLists for handling arrays -->
-        <xsl:for-each select="property">
-            <xsl:if test="@array">
-                java.util.ArrayList list<xsl:value-of select="position()"></xsl:value-of> = new java.util.ArrayList(5000);
-            </xsl:if>
+        </xsl:if>
+
+        <!-- populate attributes here!!!. The attributes are part of an element, not part of a
+             type -->
+        <xsl:for-each select="property[@attribute]">
+            <xsl:variable name="propertyName"><xsl:value-of select="@name"/></xsl:variable>
+            <xsl:variable name="propertyType"><xsl:value-of select="@type"/></xsl:variable>
+            <xsl:variable name="shortTypeName"><xsl:value-of select="@shorttypename"/></xsl:variable>
+            <xsl:variable name="javaName"><xsl:value-of select="@javaname"></xsl:value-of></xsl:variable>
+            <xsl:variable name="namespace"><xsl:value-of select="@nsuri"/></xsl:variable>
+
+
+           object.set<xsl:value-of select="$javaName"/>(
+                   org.apache.axis2.databinding.utils.ConverterUtil.convertTo<xsl:value-of select="$shortTypeName"/>(
+           reader.getAttributeValue("<xsl:value-of select="$namespace"/>","<xsl:value-of select="$propertyName"/>")));
+
         </xsl:for-each>
-        while(!done){
-        if (javax.xml.stream.XMLStreamConstants.START_ELEMENT==event){
-        <!-- Now reloop and populate the code -->
-        <xsl:for-each select="property">
+
+        <!-- Now reloop and populate the code for non-attribute values-->
+        <xsl:for-each select="property[not(@attribute)]">
             <xsl:variable name="propertyName"><xsl:value-of select="@name"/></xsl:variable>
             <xsl:variable name="propertyType"><xsl:value-of select="@type"/></xsl:variable>
             <xsl:variable name="shortTypeName"><xsl:value-of select="@shorttypename"/></xsl:variable>
             <xsl:variable name="javaName"><xsl:value-of select="@javaname"></xsl:value-of></xsl:variable>
             <xsl:variable name="listName">list<xsl:value-of select="position()"/></xsl:variable>
             <xsl:variable name="loopBoolName">loopDone<xsl:value-of select="position()"/></xsl:variable>
+            <xsl:variable name="startQname">startQname<xsl:value-of select="position()"/></xsl:variable>
+            <xsl:variable name="stateMachineName">stateMachine<xsl:value-of select="position()"/></xsl:variable>
+            <xsl:variable name="builderName">builder<xsl:value-of select="position()"/></xsl:variable>
+            <xsl:variable name="basePropertyType"><xsl:value-of select="@arrayBaseType"/></xsl:variable>
+            <xsl:variable name="namespace"><xsl:value-of select="@nsuri"/></xsl:variable>
+
 
-            if ("<xsl:value-of select="$propertyName"/>".equals(reader.getLocalName())){
             <xsl:choose>
+                <!-- Start of array handling code -->
                 <xsl:when test="@array">
-                    <xsl:variable name="basePropertyType"><xsl:value-of select="@arrayBaseType"/></xsl:variable>
                     <xsl:choose>
                         <xsl:when test="@ours">
-                            <xsl:value-of select="$listName"/>.add(<xsl:value-of select="$basePropertyType"/>.Factory.parse(reader));
-                            //loop until we find a start element that is not part of this array
-                            boolean <xsl:value-of select="$loopBoolName"/> = false;
-                            while(!<xsl:value-of select="$loopBoolName"/>){
-                            //loop to the end element
-                            while (!reader.isEndElement()){
-                            event = reader.next();
-                            }
-                            //step one event
-                            event = reader.next();
-                            if (reader.isEndElement() &amp;&amp;  !"<xsl:value-of select="$propertyName"/>".equals(reader.getLocalName())){
-                            //two continuous end elements means we are exiting the xml structure
-                            <xsl:value-of select="$loopBoolName"/> = true;
-                            }else if (reader.isStartElement()){
-                            if ("<xsl:value-of select="$propertyName"/>".equals(reader.getLocalName())){
-                            <xsl:value-of select="$listName"/>.add(<xsl:value-of select="$basePropertyType"/>.Factory.parse(reader));
-                            }else{
-                            <xsl:value-of select="$loopBoolName"/> = true;
-                            }
-                            }
-                            }
+                               <!-- Somebody put the magic number 5000 here. I wonder who did that! -->
+                             java.util.ArrayList <xsl:value-of select="$listName"/> = new java.util.ArrayList();
+                            <!-- Start of Array handling of ADB classes -->
+                             boolean <xsl:value-of select="$loopBoolName"/>=false;
+                             javax.xml.namespace.QName <xsl:value-of select="$startQname"/> = new javax.xml.namespace.QName(
+                                    "<xsl:value-of select="$namespace"/>",
+                                    "<xsl:value-of select="$propertyName"/>");
+
+                                while (!<xsl:value-of select="$loopBoolName"/>){
+                                    event = reader.getEventType();
+                                    if (javax.xml.stream.XMLStreamConstants.START_ELEMENT == event
+                                            &amp;&amp; <xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                                       <xsl:value-of select="$listName"/>.add(<xsl:value-of select="$basePropertyType"/>.Factory.parse(reader));
+                                    } else if (javax.xml.stream.XMLStreamConstants.END_ELEMENT == event &amp;&amp;
+                                        <xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                                        <xsl:value-of select="$loopBoolName"/> = true;
+                                    }else{
+                                        reader.next();
+                                    }
 
+                                }
 
-                            // call the converter utility  to convert and set the array
                             object.set<xsl:value-of select="$javaName"/>(
-                            (<xsl:value-of select="$propertyType"/>)
-                            org.apache.axis2.databinding.utils.ConverterUtil.convertToArray(
-                            <xsl:value-of select="$basePropertyType"/>.class,
-                            <xsl:value-of select="$listName"/>));
+                                (<xsl:value-of select="$propertyType"/>)
+                               org.apache.axis2.databinding.utils.ConverterUtil.convertToArray(
+                               <xsl:value-of select="$basePropertyType"/>.class,<xsl:value-of select="$listName"/>));
 
-                            count++;
+                            //move to the next event, probably past the last end_element event
+                            reader.next();
                         </xsl:when>
-                        <xsl:otherwise>
-                            <xsl:value-of select="$listName"/>.add(reader.getElementText());
-                            //loop until we find a start element that is not part of this array
-                            boolean <xsl:value-of select="$loopBoolName"/> = false;
-                            while(!<xsl:value-of select="$loopBoolName"/>){
-                            //loop to the end element
-                            while (!reader.isEndElement()){
-                            event = reader.next();
-                            }
-                            //step one event
-                            event = reader.next();
-                            if (reader.isEndElement() &amp;&amp;  !"<xsl:value-of select="$propertyName"/>".equals(reader.getLocalName())){
-                            //two continuous end elements means we are exiting the xml structure
-                            <xsl:value-of select="$loopBoolName"/> = true;
-                            }else if (reader.isStartElement()){
-                            if ("<xsl:value-of select="$propertyName"/>".equals(reader.getLocalName())){
-                            <xsl:value-of select="$listName"/>.add(reader.getElementText());
-                            }else{
-                            <xsl:value-of select="$loopBoolName"/> = true;
-                            }
-                            }
-                            }
+                        <xsl:when test="@default">
+                             <!-- Somebody put the magic number 5000 here. I wonder who did that! -->
+                             java.util.ArrayList <xsl:value-of select="$listName"/> = new java.util.ArrayList();
+                             boolean <xsl:value-of select="$loopBoolName"/>=false;
+                             javax.xml.namespace.QName <xsl:value-of select="$startQname"/> = new javax.xml.namespace.QName(
+                                    "<xsl:value-of select="$namespace"/>",
+                                    "<xsl:value-of select="$propertyName"/>");
+                            <xsl:variable name="internalLoopVar"><xsl:value-of select="$loopBoolName"/>_internal</xsl:variable>
+                                    boolean <xsl:value-of select="$internalLoopVar"/> = false;
+
+                                    while(!<xsl:value-of select="$internalLoopVar"/>){
+                                        if (reader.isStartElement() &amp;&amp; <xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                                            <xsl:value-of select="$internalLoopVar"/> = true;
+                                        }else{
+                                            reader.next();
+                                        }
+                                }
+
+                                while (!<xsl:value-of select="$loopBoolName"/>){
+                                    event = reader.getEventType();
+                                    if (javax.xml.stream.XMLStreamConstants.START_ELEMENT == event
+                                            &amp;&amp; <xsl:value-of select="$startQname"/>.equals(reader.getName())){
+
+                                    // We need to wrap the reader so that it produces a fake START_DOCUEMENT event
+                                    org.apache.axis2.databinding.utils.NamedStaxOMBuilder <xsl:value-of select="$builderName"/> = new org.apache.axis2.databinding.utils.NamedStaxOMBuilder(
+                                            new org.apache.axis2.util.StreamWrapper(reader),<xsl:value-of select="$startQname"/>);
+                                   <xsl:value-of select="$listName"/>.add(<xsl:value-of select="$builderName"/>.getOMElement());
+
+                                    } else if (javax.xml.stream.XMLStreamConstants.START_ELEMENT == event &amp;&amp;
+                                        !<xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                                        <xsl:value-of select="$loopBoolName"/> = true;
+                                    }else if (javax.xml.stream.XMLStreamConstants.END_ELEMENT == event &amp;&amp;
+                                        !<xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                                        <xsl:value-of select="$loopBoolName"/> = true;
+                                    }else if (javax.xml.stream.XMLStreamConstants.END_DOCUMENT == event){
+                                        <xsl:value-of select="$loopBoolName"/> = true;
+                                    }else{
+                                        reader.next();
+                                    }
 
-                            // call the converter utility  to convert and set the array
-                            object.set<xsl:value-of select="$javaName"/>(
-                            (<xsl:value-of select="$propertyType"/>)
-                            org.apache.axis2.databinding.utils.ConverterUtil.convertToArray(
-                            <xsl:value-of select="$basePropertyType"/>.class,
-                            <xsl:value-of select="$listName"/>));
-                            count++;
-                        </xsl:otherwise>
-                    </xsl:choose>
-                </xsl:when>
-                <xsl:when test="@ours">
-                    object.set<xsl:value-of select="$javaName"/>(
-                    <xsl:value-of select="$propertyType"/>.Factory.parse(reader));
-                    count++;
-                </xsl:when>
-                <xsl:when test="@any">
-                    //do nothing yet!!!!
-                </xsl:when>
-                <xsl:otherwise>
-                    String content = reader.getElementText();
-                    object.set<xsl:value-of select="$javaName"/>(
-                    org.apache.axis2.databinding.utils.ConverterUtil.convertTo<xsl:value-of select="$shortTypeName"/>(content));
-                    count++;
-                </xsl:otherwise>
-            </xsl:choose>
+                                }
 
-            }
+                            object.set<xsl:value-of select="$javaName"/>(
+                                (<xsl:value-of select="$propertyType"/>)
+                               org.apache.axis2.databinding.utils.ConverterUtil.convertToArray(
+                               <xsl:value-of select="$basePropertyType"/>.class,<xsl:value-of select="$listName"/>));
 
-        </xsl:for-each>
-        }
+                        </xsl:when>
+                        <!-- End of Array handling of ADB classes -->
+                        <xsl:otherwise>
+                           <!-- Start of Array handling of simple types -->
+                            org.apache.axis2.databinding.utils.SimpleArrayReaderStateMachine <xsl:value-of select="$stateMachineName"/> = new
+                                                            org.apache.axis2.databinding.utils.SimpleArrayReaderStateMachine();
+                            <xsl:value-of select="$stateMachineName"/>.setElementNameToTest(new javax.xml.namespace.QName(
+                            "<xsl:value-of select="$namespace"/>",
+                            "<xsl:value-of select="$propertyName"/>"));
+                            <xsl:value-of select="$stateMachineName"/>.read(reader);
+                            String[] textArray = <xsl:value-of select="$stateMachineName"/>.getTextArray();
+                            object.set<xsl:value-of select="$javaName"/>(
+                             (<xsl:value-of select="$propertyType"/>)
+                               org.apache.axis2.databinding.utils.ConverterUtil.convertToArray(
+                               <xsl:value-of select="$basePropertyType"/>.class,<xsl:value-of select="$stateMachineName"/>.getTextArray()));
 
-        if (argumentCount==count){
-        done=true;
-        }
+                           <!-- end of Array handling of simple types -->
+                        </xsl:otherwise>
+                    </xsl:choose>
+             </xsl:when>
+             <!--  end of array handling -->
 
-        if (!done){
-        event = reader.next();
-        }
+              <xsl:when test="@ours">
+                  object.set<xsl:value-of select="$javaName"/>(<xsl:value-of select="$propertyType"/>.Factory.parse(
+                                        reader));
+              </xsl:when>
+              <!-- end of adb type handling code -->
+              <!-- start of OMelement handling -->
+               <xsl:when test="@default">
+                boolean <xsl:value-of select="$loopBoolName"/> = false;
+                javax.xml.namespace.QName <xsl:value-of select="$startQname"/> = new javax.xml.namespace.QName(
+                                                       "<xsl:value-of select="$namespace"/>",
+                                                       "<xsl:value-of select="$propertyName"/>");
+
+                while(!<xsl:value-of select="$loopBoolName"/>){
+                    if (reader.isStartElement() &amp;&amp; <xsl:value-of select="$startQname"/>.equals(reader.getName())){
+                        <xsl:value-of select="$loopBoolName"/> = true;
+                    }else{
+                        reader.next();
+                    }
+                }
+
+                // We need to wrap the reader so that it produces a fake START_DOCUEMENT event
+                org.apache.axis2.databinding.utils.NamedStaxOMBuilder <xsl:value-of select="$builderName"/> = new org.apache.axis2.databinding.utils.NamedStaxOMBuilder(
+                        new org.apache.axis2.util.StreamWrapper(reader),<xsl:value-of select="$startQname"/>);
+                object.set<xsl:value-of select="$javaName"/>(<xsl:value-of select="$builderName"/>.getOMElement());
+
+                //step one more event from the current position
+                reader.next();
+              </xsl:when>
+              <!-- end of OMelement handling -->
+              <!-- start of the simple types handling -->
+              <xsl:otherwise>
+                org.apache.axis2.databinding.utils.SimpleElementReaderStateMachine <xsl:value-of select="$stateMachineName"/>
+                  = new org.apache.axis2.databinding.utils.SimpleElementReaderStateMachine();
+                javax.xml.namespace.QName <xsl:value-of select="$startQname"/> = new javax.xml.namespace.QName(
+                                     "<xsl:value-of select="$namespace"/>",
+                                    "<xsl:value-of select="$propertyName"/>");
+                <xsl:value-of select="$stateMachineName"/>.setElementNameToTest(<xsl:value-of select="$startQname"/>);
+                <xsl:value-of select="$stateMachineName"/>.read(reader);
+                object.set<xsl:value-of select="$javaName"/>(
+                   org.apache.axis2.databinding.utils.ConverterUtil.convertTo<xsl:value-of select="$shortTypeName"/>(
+                   <xsl:value-of select="$stateMachineName"/>.getText()));
+              </xsl:otherwise>
+               <!-- end of simple type handling -->
 
-        }
+            </xsl:choose>
 
+         </xsl:for-each>
         } catch (javax.xml.stream.XMLStreamException e) {
-        throw new java.lang.Exception(e);
+             throw new java.lang.Exception(e);
         }
 
         return object;

Modified: webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/writer/JavaBeanWriter.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/writer/JavaBeanWriter.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/writer/JavaBeanWriter.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/src/org/apache/axis2/schema/writer/JavaBeanWriter.java Sat Feb  4 04:20:54 2006
@@ -488,7 +488,8 @@
      * @return
      */
     private boolean isDefault(String javaClassNameForElement) {
-        return SchemaCompiler.DEFAULT_CLASS_NAME.equals(javaClassNameForElement);
+        return SchemaCompiler.DEFAULT_CLASS_NAME.equals(javaClassNameForElement)||
+                SchemaCompiler.DEFAULT_CLASS_ARRAY_NAME.equals(javaClassNameForElement);
     }
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/anonymous_complexType.xsd
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/anonymous_complexType.xsd?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/anonymous_complexType.xsd (original)
+++ webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/anonymous_complexType.xsd Sat Feb  4 04:20:54 2006
@@ -1,7 +1,8 @@
 <schema xmlns="http://www.w3.org/2001/XMLSchema"
         xmlns:xsd="http://www.w3.org/2001/XMLSchema"
         xmlns:tns="http://soapinterop.org1/types"
-        targetNamespace="http://soapinterop.org1/types">
+        targetNamespace="http://soapinterop.org1/types"
+        elementFormDefault="qualified">
     <element name="tempElt">
         <complexType>
             <sequence>

Modified: webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_anytype.xsd
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_anytype.xsd?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_anytype.xsd (original)
+++ webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_anytype.xsd Sat Feb  4 04:20:54 2006
@@ -1,4 +1,4 @@
-<schema targetNamespace="http://soapinterop.org/xsd"
+<schema targetNamespace="http://soapinterop.org/xsd2"
         xmlns="http://www.w3.org/2001/XMLSchema"
         xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
         xmlns:xsd="http://www.w3.org/2001/XMLSchema"

Modified: webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_sequence.xsd
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_sequence.xsd?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_sequence.xsd (original)
+++ webservices/axis2/trunk/java/modules/codegen/test-resources/xsd/simple_sequence.xsd Sat Feb  4 04:20:54 2006
@@ -1,14 +1,14 @@
 <schema xmlns="http://www.w3.org/2001/XMLSchema"
         xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-            xmlns:tns="http://soapinterop.org/types"
-			targetNamespace="http://soapinterop.org/types">
-			<import namespace="http://schemas.xmlsoap.org/soap/encoding/"/>
-			<complexType name="SOAPStruct">
-				<sequence>
-					<element name="varString" type="xsd:string"/>
-					<element name="varInt" type="xsd:int"/>
-					<element name="varFloat" type="xsd:float"/>
-				</sequence>
-			</complexType>
-            <element name="myElement" type="tns:SOAPStruct"/>
-        </schema>
\ No newline at end of file
+        xmlns:tns="http://soapinterop.org/types"
+        targetNamespace="http://soapinterop.org/types">
+    <import namespace="http://schemas.xmlsoap.org/soap/encoding/"/>
+    <complexType name="SOAPStruct">
+        <sequence>
+            <element name="varString" type="xsd:string"/>
+            <element name="varInt" type="xsd:int"/>
+            <element name="varFloat" type="xsd:float"/>
+        </sequence>
+    </complexType>
+    <element name="myElement" type="tns:SOAPStruct"/>
+</schema>
\ No newline at end of file

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeBytePopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeBytePopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeBytePopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeBytePopulateTest.java Sat Feb  4 04:20:54 2006
@@ -26,9 +26,9 @@
             "2"
     };
     private String xmlString[] = {
-            "<DerivedByte>"+values[0]+"</DerivedByte>",
-            "<DerivedByte>"+values[1]+"</DerivedByte>",
-            "<DerivedByte>"+values[2]+"</DerivedByte>"
+            "<DerivedByte xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedByte>",
+            "<DerivedByte xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedByte>",
+            "<DerivedByte xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedByte>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -27,9 +27,9 @@
 
 
     private String xmlString[] = {
-            "<DerivedInt>"+values[0]+"</DerivedInt>",
-            "<DerivedInt>"+values[1]+"</DerivedInt>",
-            "<DerivedInt>"+values[2]+"</DerivedInt>"
+            "<DerivedInt xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedInt>",
+            "<DerivedInt xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedInt>",
+            "<DerivedInt xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedInt>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntegerPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntegerPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntegerPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeIntegerPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -28,9 +28,9 @@
             "-2344556"
     };
     private String xmlString[] = {
-            "<DerivedInteger>"+values[0]+"</DerivedInteger>",
-            "<DerivedInteger>"+values[1]+"</DerivedInteger>",
-            "<DerivedInteger>"+values[2]+"</DerivedInteger>"
+            "<DerivedInteger xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedInteger>",
+            "<DerivedInteger xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedInteger>",
+            "<DerivedInteger xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedInteger>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeLongPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeLongPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeLongPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeLongPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -29,11 +29,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedLong>"+values[0]+"</DerivedLong>",
-            "<DerivedLong>"+values[1]+"</DerivedLong>",
-            "<DerivedLong>"+values[2]+"</DerivedLong>",
-            "<DerivedLong>"+values[3]+"</DerivedLong>",
-            "<DerivedLong>"+values[4]+"</DerivedLong>"
+            "<DerivedLong xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedLong>",
+            "<DerivedLong xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedLong>",
+            "<DerivedLong xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedLong>",
+            "<DerivedLong xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedLong>",
+            "<DerivedLong xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedLong>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNegativeIntegerPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNegativeIntegerPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNegativeIntegerPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNegativeIntegerPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -29,11 +29,11 @@
             "0",
     };
     private String xmlString[] = {
-            "<DerivedNegativeInteger>"+values[0]+"</DerivedNegativeInteger>",
-            "<DerivedNegativeInteger>"+values[1]+"</DerivedNegativeInteger>",
-            "<DerivedNegativeInteger>"+values[2]+"</DerivedNegativeInteger>",
-            "<DerivedNegativeInteger>"+values[3]+"</DerivedNegativeInteger>",
-            "<DerivedNegativeInteger>"+values[4]+"</DerivedNegativeInteger>"
+            "<DerivedNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedNegativeInteger>",
+            "<DerivedNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedNegativeInteger>",
+            "<DerivedNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedNegativeInteger>",
+            "<DerivedNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedNegativeInteger>",
+            "<DerivedNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedNegativeInteger>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonNegativeIntegerPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonNegativeIntegerPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonNegativeIntegerPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonNegativeIntegerPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedNonNegativeInteger>"+values[0]+"</DerivedNonNegativeInteger>",
-            "<DerivedNonNegativeInteger>"+values[1]+"</DerivedNonNegativeInteger>",
-            "<DerivedNonNegativeInteger>"+values[2]+"</DerivedNonNegativeInteger>",
-            "<DerivedNonNegativeInteger>"+values[3]+"</DerivedNonNegativeInteger>",
-            "<DerivedNonNegativeInteger>"+values[4]+"</DerivedNonNegativeInteger>"
+            "<DerivedNonNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedNonNegativeInteger>",
+            "<DerivedNonNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedNonNegativeInteger>",
+            "<DerivedNonNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedNonNegativeInteger>",
+            "<DerivedNonNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedNonNegativeInteger>",
+            "<DerivedNonNegativeInteger xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedNonNegativeInteger>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonPositiveIntegerPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonPositiveIntegerPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonPositiveIntegerPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeNonPositiveIntegerPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedNonPositiveInteger>"+values[0]+"</DerivedNonPositiveInteger>",
-            "<DerivedNonPositiveInteger>"+values[1]+"</DerivedNonPositiveInteger>",
-            "<DerivedNonPositiveInteger>"+values[2]+"</DerivedNonPositiveInteger>",
-            "<DerivedNonPositiveInteger>"+values[3]+"</DerivedNonPositiveInteger>",
-            "<DerivedNonPositiveInteger>"+values[4]+"</DerivedNonPositiveInteger>"
+            "<DerivedNonPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedNonPositiveInteger>",
+            "<DerivedNonPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedNonPositiveInteger>",
+            "<DerivedNonPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedNonPositiveInteger>",
+            "<DerivedNonPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedNonPositiveInteger>",
+            "<DerivedNonPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedNonPositiveInteger>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypePositveIntegerPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypePositveIntegerPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypePositveIntegerPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypePositveIntegerPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedPositiveInteger>"+values[0]+"</DerivedPositiveInteger>",
-            "<DerivedPositiveInteger>"+values[1]+"</DerivedPositiveInteger>",
-            "<DerivedPositiveInteger>"+values[2]+"</DerivedPositiveInteger>",
-            "<DerivedPositiveInteger>"+values[3]+"</DerivedPositiveInteger>",
-            "<DerivedPositiveInteger>"+values[4]+"</DerivedPositiveInteger>"
+            "<DerivedPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedPositiveInteger>",
+            "<DerivedPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedPositiveInteger>",
+            "<DerivedPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedPositiveInteger>",
+            "<DerivedPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedPositiveInteger>",
+            "<DerivedPositiveInteger xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedPositiveInteger>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeShortPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeShortPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeShortPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeShortPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -30,11 +30,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedShort>"+values[0]+"</DerivedShort>",
-            "<DerivedShort>"+values[1]+"</DerivedShort>",
-            "<DerivedShort>"+values[2]+"</DerivedShort>",
-            "<DerivedShort>"+values[3]+"</DerivedShort>",
-            "<DerivedShort>"+values[4]+"</DerivedShort>"
+            "<DerivedShort xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedShort>",
+            "<DerivedShort xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedShort>",
+            "<DerivedShort xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedShort>",
+            "<DerivedShort xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedShort>",
+            "<DerivedShort xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedShort>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedBytePopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedBytePopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedBytePopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedBytePopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedUnsignedByte>"+values[0]+"</DerivedUnsignedByte>",
-            "<DerivedUnsignedByte>"+values[1]+"</DerivedUnsignedByte>",
-            "<DerivedUnsignedByte>"+values[2]+"</DerivedUnsignedByte>",
-            "<DerivedUnsignedByte>"+values[3]+"</DerivedUnsignedByte>",
-            "<DerivedUnsignedByte>"+values[4]+"</DerivedUnsignedByte>"
+            "<DerivedUnsignedByte xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedUnsignedByte>",
+            "<DerivedUnsignedByte xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedUnsignedByte>",
+            "<DerivedUnsignedByte xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedUnsignedByte>",
+            "<DerivedUnsignedByte xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedUnsignedByte>",
+            "<DerivedUnsignedByte xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedUnsignedByte>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedIntPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedIntPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedIntPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedIntPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedUnsignedInt>"+values[0]+"</DerivedUnsignedInt>",
-            "<DerivedUnsignedInt>"+values[1]+"</DerivedUnsignedInt>",
-            "<DerivedUnsignedInt>"+values[2]+"</DerivedUnsignedInt>",
-            "<DerivedUnsignedInt>"+values[3]+"</DerivedUnsignedInt>",
-            "<DerivedUnsignedInt>"+values[4]+"</DerivedUnsignedInt>"
+            "<DerivedUnsignedInt xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedUnsignedInt>",
+            "<DerivedUnsignedInt xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedUnsignedInt>",
+            "<DerivedUnsignedInt xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedUnsignedInt>",
+            "<DerivedUnsignedInt xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedUnsignedInt>",
+            "<DerivedUnsignedInt xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedUnsignedInt>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedLongPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedLongPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedLongPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedLongPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedUnsignedLong>"+values[0]+"</DerivedUnsignedLong>",
-            "<DerivedUnsignedLong>"+values[1]+"</DerivedUnsignedLong>",
-            "<DerivedUnsignedLong>"+values[2]+"</DerivedUnsignedLong>",
-            "<DerivedUnsignedLong>"+values[3]+"</DerivedUnsignedLong>",
-            "<DerivedUnsignedLong>"+values[4]+"</DerivedUnsignedLong>"
+            "<DerivedUnsignedLong xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedUnsignedLong>",
+            "<DerivedUnsignedLong xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedUnsignedLong>",
+            "<DerivedUnsignedLong xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</DerivedUnsignedLong>",
+            "<DerivedUnsignedLong xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedUnsignedLong>",
+            "<DerivedUnsignedLong xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedUnsignedLong>"
     };
 
 

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedShortPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedShortPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedShortPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/derived/DerivedTypeUnsignedShortPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -31,11 +31,11 @@
     };
 
     private String xmlString[] = {
-            "<DerivedUnsignedShort>"+values[0]+"</DerivedUnsignedShort>",
-            "<DerivedUnsignedShort>"+values[1]+"</DerivedUnsignedShort>",
-            "<DerivedUnsignedShort>"+values[2]+"</DerivedUnsignedShort>",
-            "<DerivedUnsignedShort>"+values[3]+"</DerivedUnsignedShort>",
-            "<DerivedUnsignedShort>"+values[4]+"</DerivedUnsignedShort>"
+            "<DerivedUnsignedShort xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</DerivedUnsignedShort>",
+            "<DerivedUnsignedShort xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</DerivedUnsignedShort>",
+            "<DerivedUnsignedShort xmlns=\"http://soapinterop.org/xsd\" >"+values[2]+"</DerivedUnsignedShort>",
+            "<DerivedUnsignedShort xmlns=\"http://soapinterop.org/xsd\">"+values[3]+"</DerivedUnsignedShort>",
+            "<DerivedUnsignedShort xmlns=\"http://soapinterop.org/xsd\">"+values[4]+"</DerivedUnsignedShort>"
     };
 
 

Copied: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnonComplexTypeTest.java (from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateAnonComplexTypeTest.java)
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnonComplexTypeTest.java?p2=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnonComplexTypeTest.java&p1=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateAnonComplexTypeTest.java&r1=374670&r2=374862&rev=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateAnonComplexTypeTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnonComplexTypeTest.java Sat Feb  4 04:20:54 2006
@@ -1,4 +1,4 @@
-package org.apache.axis2.schema.populate;
+package org.apache.axis2.schema.populate.other;
 
 import junit.framework.TestCase;
 
@@ -28,9 +28,9 @@
  */
 
 public class PopulateAnonComplexTypeTest extends TestCase {
-    private String xmlString = "<tempElt>" +
-            "<varInt>5</varInt>" +
+    private String xmlString = "<tempElt xmlns=\"http://soapinterop.org1/types\">" +
             "<varString>Hello</varString>" +
+            "<varInt>5</varInt>" +
             "<varFloat>3.3</varFloat>" +
             "</tempElt>";
 

Added: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnyTypeTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnyTypeTest.java?rev=374862&view=auto
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnyTypeTest.java (added)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateAnyTypeTest.java Sat Feb  4 04:20:54 2006
@@ -0,0 +1,51 @@
+package org.apache.axis2.schema.populate.other;
+
+import junit.framework.TestCase;
+
+import javax.xml.stream.XMLStreamReader;
+import javax.xml.stream.XMLInputFactory;
+import java.io.ByteArrayInputStream;
+import java.lang.reflect.Method;
+/*
+ * Copyright 2004,2005 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+public class PopulateAnyTypeTest extends TestCase {
+
+     private String xmlString = "<myObject xmlns=\"http://soapinterop.org/xsd2\">" +
+            "<soapStructures>" +
+            "<varFloat>3.3</varFloat>" +
+            "<varInt>5</varInt>" +
+            "<varString>Hello11</varString>" +
+            "<varString>Hello11</varString>" +
+            "<varString>Hello12</varString>" +
+            "<varString>Hello13</varString>" +
+            "</soapStructures>" +
+            "</myObject>";
+
+    public void testPopulate() throws Exception{
+
+               XMLStreamReader reader = XMLInputFactory.newInstance().createXMLStreamReader(new ByteArrayInputStream(xmlString.getBytes()));
+               Class clazz = Class.forName("org.soapinterop.xsd2.MyObject");
+               Class innerClazz = clazz.getDeclaredClasses()[0];
+               Method parseMethod = innerClazz.getMethod("parse",new Class[]{XMLStreamReader.class});
+               Object obj = parseMethod.invoke(null,new Object[]{reader});
+
+
+
+
+    }
+
+}

Copied: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayInArrayTest.java (from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayInArrayTest.java)
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayInArrayTest.java?p2=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayInArrayTest.java&p1=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayInArrayTest.java&r1=374670&r2=374862&rev=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayInArrayTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayInArrayTest.java Sat Feb  4 04:20:54 2006
@@ -1,4 +1,4 @@
-package org.apache.axis2.schema.populate;
+package org.apache.axis2.schema.populate.other;
 
 import junit.framework.TestCase;
 
@@ -26,7 +26,7 @@
  */
 
 public class PopulateArrayInArrayTest extends TestCase{
-    private String xmlString = "<myobject>" +
+    private String xmlString = "<myobject xmlns=\"http://soapinterop.org/xsd\">" +
             "<soapStructures>" +
             "<varFloat>3.3</varFloat>" +
             "<varInt>5</varInt>" +

Copied: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayTest.java (from r374670, webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayTest.java)
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayTest.java?p2=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayTest.java&p1=webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayTest.java&r1=374670&r2=374862&rev=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/PopulateArrayTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/other/PopulateArrayTest.java Sat Feb  4 04:20:54 2006
@@ -1,4 +1,4 @@
-package org.apache.axis2.schema.populate;
+package org.apache.axis2.schema.populate.other;
 
 import junit.framework.TestCase;
 
@@ -27,7 +27,7 @@
  */
 
 public class PopulateArrayTest extends TestCase {
-    private String xmlString = "<myobject>" +
+    private String xmlString = "<myobject xmlns=\"http://soapinterop.org2/xsd\">" +
             "<varFloat>3.3</varFloat>" +
             "<varInt>5</varInt>" +
             "<varString>Hello</varString>" +

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeAnyURIPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeAnyURIPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeAnyURIPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeAnyURIPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -22,9 +22,9 @@
             "ftp://grad/education/mas/229.html",
             "http://mail.google.com/mail/?auth=DQAAAHEAAAC041"};
     private String xmlString[] = {
-            "<anyURIParam>" + values[0]+"</anyURIParam>",
-            "<anyURIParam>" + values[1]+"</anyURIParam>",
-            "<anyURIParam>" + values[2]+"</anyURIParam>"
+            "<anyURIParam xmlns=\"http://soapinterop.org/xsd\">" + values[0]+"</anyURIParam>",
+            "<anyURIParam xmlns=\"http://soapinterop.org/xsd\">" + values[1]+"</anyURIParam>",
+            "<anyURIParam xmlns=\"http://soapinterop.org/xsd\">" + values[2]+"</anyURIParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBase64BinPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBase64BinPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBase64BinPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBase64BinPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -18,8 +18,8 @@
 
 public class SimpleTypeBase64BinPopulateTest extends AbstractSimplePopulater{
     private String xmlString[] = {
-            "<base64BinParam>abcdABCD</base64BinParam>",
-            "<base64BinParam>abcdABCD09rT</base64BinParam>",
+            "<base64BinParam xmlns=\"http://soapinterop.org/xsd\">abcdABCD</base64BinParam>",
+            "<base64BinParam xmlns=\"http://soapinterop.org/xsd\">abcdABCD09rT</base64BinParam>",
     };
 
      protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBooleanPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBooleanPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBooleanPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeBooleanPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -23,8 +23,8 @@
     };
 
     private String xmlString[] = {
-            "<booleanParam>"+ values[0] +"</booleanParam>",
-            "<booleanParam>"+ values[1] +"</booleanParam>",
+            "<booleanParam xmlns=\"http://soapinterop.org/xsd\">"+ values[0] +"</booleanParam>",
+            "<booleanParam xmlns=\"http://soapinterop.org/xsd\">"+ values[1] +"</booleanParam>",
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDatePopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDatePopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDatePopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDatePopulateTest.java Sat Feb  4 04:20:54 2006
@@ -26,9 +26,9 @@
                 "2002-02-28"
     } ;
     private String xmlString[] = {
-            "<dateParam>"+values[0]+"</dateParam>",
-            "<dateParam>"+values[1]+"</dateParam>",
-            "<dateParam>"+values[2]+"</dateParam>"
+            "<dateParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</dateParam>",
+            "<dateParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</dateParam>",
+            "<dateParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</dateParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDateTimePopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDateTimePopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDateTimePopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDateTimePopulateTest.java Sat Feb  4 04:20:54 2006
@@ -25,9 +25,9 @@
             "2002-10-10T07:00:00Z"
     };
     private String xmlString[] = {
-            "<dateTimeParam>"+values[0]+"</dateTimeParam>",
-            "<dateTimeParam>"+values[1]+"</dateTimeParam>",
-            "<dateTimeParam>"+values[2]+"</dateTimeParam>"
+            "<dateTimeParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</dateTimeParam>",
+            "<dateTimeParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</dateTimeParam>",
+            "<dateTimeParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</dateTimeParam>"
     };
     // force others to implement this method
     public void testPopulate() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDayPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDayPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDayPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDayPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -25,9 +25,9 @@
                         "---12"
     };
     private String xmlString[] = {
-            "<dayParam>"+values[0]+"</dayParam>",
-            "<dayParam>"+values[1]+"</dayParam>",
-            "<dayParam>"+values[2]+"</dayParam>"
+            "<dayParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</dayParam>",
+            "<dayParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</dayParam>",
+            "<dayParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</dayParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDoublePopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDoublePopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDoublePopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDoublePopulateTest.java Sat Feb  4 04:20:54 2006
@@ -24,9 +24,9 @@
             "66733.0060604343"
     };
     private String xmlString[] = {
-            "<doubleParam>"+values[0]+"</doubleParam>",
-            "<doubleParam>"+values[1]+"</doubleParam>",
-            "<doubleParam>"+values[2]+"</doubleParam>"
+            "<doubleParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</doubleParam>",
+            "<doubleParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</doubleParam>",
+            "<doubleParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</doubleParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDurationPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDurationPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDurationPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeDurationPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -26,9 +26,9 @@
     };
 
     private String xmlString[] = {
-            "<durationParam>"+values[0]+"</durationParam>",
-            "<durationParam>"+values[1]+"</durationParam>",
-            "<durationParam>"+values[2]+"</durationParam>"
+            "<durationParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</durationParam>",
+            "<durationParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</durationParam>",
+            "<durationParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</durationParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeFloatPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeFloatPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeFloatPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeFloatPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -28,9 +28,9 @@
 
 
     private String xmlString[] = {
-            "<floatParam>"+values[0]+"</floatParam>",
-            "<floatParam>"+values[1]+"</floatParam>",
-            "<floatParam>"+values[2]+"</floatParam>"
+            "<floatParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</floatParam>",
+            "<floatParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</floatParam>",
+            "<floatParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</floatParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeHexBinaryPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeHexBinaryPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeHexBinaryPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeHexBinaryPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -26,9 +26,9 @@
             "1978"
     };
     private String xmlString[] = {
-            "<hexBinParam>"+values[0]+"</hexBinParam>",
-            "<hexBinParam>"+values[1]+"</hexBinParam>",
-            "<hexBinParam>"+values[2]+"</hexBinParam>"
+            "<hexBinParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</hexBinParam>",
+            "<hexBinParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</hexBinParam>",
+            "<hexBinParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</hexBinParam>"
     };
 
     protected void setUp() throws Exception {

Modified: webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeMonthDayPopulateTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeMonthDayPopulateTest.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeMonthDayPopulateTest.java (original)
+++ webservices/axis2/trunk/java/modules/codegen/test/org/apache/axis2/schema/populate/simple/SimpleTypeMonthDayPopulateTest.java Sat Feb  4 04:20:54 2006
@@ -26,9 +26,9 @@
             "--12-31"
     };
     private String xmlString[] = {
-            "<monthDayParam>"+values[0]+"</monthDayParam>",
-            "<monthDayParam>"+values[1]+"</monthDayParam>",
-            "<monthDayParam>"+values[2]+"</monthDayParam>"
+            "<monthDayParam xmlns=\"http://soapinterop.org/xsd\">"+values[0]+"</monthDayParam>",
+            "<monthDayParam xmlns=\"http://soapinterop.org/xsd\">"+values[1]+"</monthDayParam>",
+            "<monthDayParam xmlns=\"http://soapinterop.org/xsd\">"+values[2]+"</monthDayParam>"
     };
 
     protected void setUp() throws Exception {
--- webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleArrayReaderStateMachine.java (original)
+++ webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleArrayReaderStateMachine.java Sat Feb  4 04:20:54 2006
@@ -31,10 +31,24 @@
     private int currentState = INIT_STATE;
     private List list = new ArrayList();
 
+    /**
+     * @return an array of strings
+     */
     public String[] getTextArray() {
         return (String[])list.toArray(new String[list.size()]);
     }
 
+
+    /**
+     * Resets the state machine. Once the reset is called
+     * the state machine is good enough for a fresh run
+     */
+    public void reset(){
+        elementNameToTest = null;
+        currentState = INIT_STATE;
+        list=new ArrayList();
+    }
+
     public void setElementNameToTest(QName elementNameToTest) {
         this.elementNameToTest = elementNameToTest;
     }
@@ -48,9 +62,11 @@
         do{
             updateState(reader);
             if (currentState==TEXT_FOUND_STATE){
                 //read the text value and store it
                 list.add(reader.getText());
             }
+            //increment the parser only if the  state is
+            //not finished
              if (currentState!=FINISHED_STATE
                 && currentState!= ILLEGAL_STATE){
                reader.next();
@@ -48,9 +62,11 @@
             updateState(reader);
             if (currentState==TEXT_FOUND_STATE){
-                //read the text value and store it
+                //read the text value and store it in the list
                 list.add(reader.getText());
             }

Modified: webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleElementReaderStateMachine.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/adb/src/org/apache/axis2/databinding/utils/SimpleElementReaderStateMachine.java?rev=374862&r1=374861&r2=374862&view=diff
==============================================================================